// Copyright 2013 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package org.chromium.ui;

import android.content.Context;
import android.graphics.Color;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.LayerDrawable;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AbsListView;
import android.widget.BaseAdapter;
import android.widget.LinearLayout;
// SHARP_EXTEND Start
import android.widget.ArrayAdapter;
// SHARP_EXTEND End

import org.chromium.base.ApiCompatibilityUtils;

/**
 * The adapter used to populate ColorPickerSimple.
 */
// SHARP_EXTEND Start
//public class ColorSuggestionListAdapter extends BaseAdapter implements View.OnClickListener {
public class ColorSuggestionListAdapter extends ArrayAdapter<ColorSuggestion> {
// SHARP_EXTEND End
    private Context mContext;
    private ColorSuggestion[] mSuggestions;
// SHARP_EXTEND Start
//    private OnColorSuggestionClickListener mListener;
//
//    /**
//     * The callback used to indicate the user has clicked on a suggestion.
//     */
//    public interface OnColorSuggestionClickListener {
//
//        /**
//         * Called upon a click on a suggestion.
//         *
//         * @param suggestion The suggestion that was clicked.
//         */
//        void onColorSuggestionClick(ColorSuggestion suggestion);
//    }
//
//    private static final int COLORS_PER_ROW = 4;
// SHARP_EXTEND End

// SHARP_EXTEND Start
//    ColorSuggestionListAdapter(Context context, ColorSuggestion[] suggestions) {
    ColorSuggestionListAdapter(Context context, int resource, ColorSuggestion[] suggestions) {
        super(context, resource, suggestions);
// SHARP_EXTEND End
        mContext = context;
        mSuggestions = suggestions;
    }

// SHARP_EXTEND Start
//    /**
//     * Sets the listener that will be notified upon a click on a suggestion.
//     */
//    public void setOnColorSuggestionClickListener(OnColorSuggestionClickListener listener) {
//        mListener = listener;
//    }
// SHARP_EXTEND End

    /**
     * Sets up the color button to represent a color suggestion.
     *
     * @param button The button view to set up.
     * @param index The index of the suggestion in mSuggestions.
     */
    private void setUpColorButton(View button, int index) {
        if (index >= mSuggestions.length) {
            button.setTag(null);
            button.setContentDescription(null);
            button.setVisibility(View.INVISIBLE);
            return;
        }
        button.setTag(mSuggestions[index]);
        button.setVisibility(View.VISIBLE);
        ColorSuggestion suggestion = mSuggestions[index];
        LayerDrawable layers = (LayerDrawable) button.getBackground();
        GradientDrawable swatch =
                (GradientDrawable) layers.findDrawableByLayerId(R.id.color_button_swatch);
        swatch.setColor(suggestion.mColor);
        String description = suggestion.mLabel;
        if (TextUtils.isEmpty(description)) {
            description = String.format("#%06X", (0xFFFFFF & suggestion.mColor));
        }
        button.setContentDescription(description);
// SHARP_EXTEND Start
//        button.setOnClickListener(this);
// SHARP_EXTEND End
    }

// SHARP_EXTEND Start
//    @Override
//    public void onClick(View v) {
//        if (mListener == null) {
//            return;
//        }
//        ColorSuggestion suggestion = (ColorSuggestion) v.getTag();
//        if (suggestion == null) {
//            return;
//        }
//        mListener.onColorSuggestionClick(suggestion);
//    }
// SHARP_EXTEND End

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        LinearLayout layout;
        if (convertView instanceof LinearLayout) {
            layout = (LinearLayout) convertView;
        } else {
            layout = new LinearLayout(mContext);
            layout.setLayoutParams(new AbsListView.LayoutParams(
                    AbsListView.LayoutParams.MATCH_PARENT,
                    AbsListView.LayoutParams.WRAP_CONTENT));
            layout.setOrientation(LinearLayout.HORIZONTAL);
// SHARP_EXTEND Start
//            layout.setBackgroundColor(Color.WHITE);
            layout.setPadding(5, 5, 5, 5);
// SHARP_EXTEND End
            int buttonHeight =
                    mContext.getResources().getDimensionPixelOffset(R.dimen.color_button_height);
// SHARP_EXTEND Start
//            for (int i = 0; i < COLORS_PER_ROW; ++i) {
//                View button = new View(mContext);
//                LinearLayout.LayoutParams layoutParams =
//                        new LinearLayout.LayoutParams(0, buttonHeight, 1f);
//                ApiCompatibilityUtils.setMarginStart(layoutParams, -1);
//                if (i == COLORS_PER_ROW - 1) {
//                    ApiCompatibilityUtils.setMarginEnd(layoutParams, -1);
//                }
//                button.setLayoutParams(layoutParams);
//                button.setBackgroundResource(R.drawable.color_button_background);
//                layout.addView(button);
//            }
            View button = new View(mContext);
            LinearLayout.LayoutParams layoutParams =
                    new LinearLayout.LayoutParams(AbsListView.LayoutParams.MATCH_PARENT, buttonHeight, 1f);
            button.setLayoutParams(layoutParams);
            button.setBackgroundResource(R.drawable.color_button_background);
            layout.addView(button);
// SHARP_EXTEND End
        }
// SHARP_EXTEND Start
//        for (int i = 0; i < COLORS_PER_ROW; ++i) {
//            setUpColorButton(layout.getChildAt(position), position * COLORS_PER_ROW + i);
//        }
        setUpColorButton(layout.getChildAt(0), position);
// SHARP_EXTEND End
        return layout;
    }

    @Override
    public long getItemId(int position) {
        return position;
    }

    @Override
// SHARP_EXTEND Start
//    public Object getItem(int position) {
//        return null;
//    }
    public ColorSuggestion getItem(int position) {
        return mSuggestions[position];
    }
// SHARP_EXTEND End

    @Override
    public int getCount() {
// SHARP_EXTEND Start
//        return (mSuggestions.length + COLORS_PER_ROW - 1) / COLORS_PER_ROW;
        return mSuggestions.length;
// SHARP_EXTEND End
    }
}
